==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/MachineLearning/AmazonSageMakerModel.md <==
# AmazonSageMakerModel


```text
aws-20210730/Resource/MachineLearning/AmazonSageMakerModel
```

```text
include('aws-20210730/Resource/MachineLearning/AmazonSageMakerModel')
```



| Illustration | AmazonSageMakerModel | AmazonSageMakerModelCard | AmazonSageMakerModelGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/MachineLearning/AmazonSageMakerModel.png) | ![illustration for AmazonSageMakerModel](../../../aws-20210730/Resource/MachineLearning/AmazonSageMakerModel.Local.png) | ![illustration for AmazonSageMakerModelCard](../../../aws-20210730/Resource/MachineLearning/AmazonSageMakerModelCard.Local.png) | ![illustration for AmazonSageMakerModelGroup](../../../aws-20210730/Resource/MachineLearning/AmazonSageMakerModelGroup.Local.png) |




## AmazonSageMakerModel

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSageMakerModel
include('aws-20210730/Resource/MachineLearning/AmazonSageMakerModel')

' renders the element
AmazonSageMakerModel('AmazonSageMakerModel', 'Amazon Sage Maker Model', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSageMakerModel
include('aws-20210730/Resource/MachineLearning/AmazonSageMakerModel')

' renders the element
AmazonSageMakerModel('AmazonSageMakerModel', 'Amazon Sage Maker Model', 'an optional tech label')
@enduml
```

## AmazonSageMakerModelCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSageMakerModelCard
include('aws-20210730/Resource/MachineLearning/AmazonSageMakerModel')

' renders the element
AmazonSageMakerModelCard('AmazonSageMakerModelCard', 'Amazon Sage Maker Model Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSageMakerModelCard
include('aws-20210730/Resource/MachineLearning/AmazonSageMakerModel')

' renders the element
AmazonSageMakerModelCard('AmazonSageMakerModelCard', 'Amazon Sage Maker Model Card', 'an optional description')
@enduml
```

## AmazonSageMakerModelGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSageMakerModelGroup
include('aws-20210730/Resource/MachineLearning/AmazonSageMakerModel')

' renders the element
AmazonSageMakerModelGroup('AmazonSageMakerModelGroup', 'Amazon Sage Maker Model Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSageMakerModelGroup
include('aws-20210730/Resource/MachineLearning/AmazonSageMakerModel')

' renders the element
AmazonSageMakerModelGroup('AmazonSageMakerModelGroup', 'Amazon Sage Maker Model Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/MachineLearning/AmazonSageMakerModel.md <==
# AmazonSageMakerModel


```text
aws-20210730/Resource/MachineLearning/AmazonSageMakerModel
```

```text
include('aws-20210730/Resource/MachineLearning/AmazonSageMakerModel')
```



| Illustration | AmazonSageMakerModel | AmazonSageMakerModelCard | AmazonSageMakerModelGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/MachineLearning/AmazonSageMakerModel.png) | ![illustration for AmazonSageMakerModel](../../../aws-20210730/Resource/MachineLearning/AmazonSageMakerModel.Local.png) | ![illustration for AmazonSageMakerModelCard](../../../aws-20210730/Resource/MachineLearning/AmazonSageMakerModelCard.Local.png) | ![illustration for AmazonSageMakerModelGroup](../../../aws-20210730/Resource/MachineLearning/AmazonSageMakerModelGroup.Local.png) |




## AmazonSageMakerModel

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSageMakerModel
include('aws-20210730/Resource/MachineLearning/AmazonSageMakerModel')

' renders the element
AmazonSageMakerModel('AmazonSageMakerModel', 'Amazon Sage Maker Model', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSageMakerModel
include('aws-20210730/Resource/MachineLearning/AmazonSageMakerModel')

' renders the element
AmazonSageMakerModel('AmazonSageMakerModel', 'Amazon Sage Maker Model', 'an optional tech label')
@enduml
```

## AmazonSageMakerModelCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSageMakerModelCard
include('aws-20210730/Resource/MachineLearning/AmazonSageMakerModel')

' renders the element
AmazonSageMakerModelCard('AmazonSageMakerModelCard', 'Amazon Sage Maker Model Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSageMakerModelCard
include('aws-20210730/Resource/MachineLearning/AmazonSageMakerModel')

' renders the element
AmazonSageMakerModelCard('AmazonSageMakerModelCard', 'Amazon Sage Maker Model Card', 'an optional description')
@enduml
```

## AmazonSageMakerModelGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSageMakerModelGroup
include('aws-20210730/Resource/MachineLearning/AmazonSageMakerModel')

' renders the element
AmazonSageMakerModelGroup('AmazonSageMakerModelGroup', 'Amazon Sage Maker Model Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSageMakerModelGroup
include('aws-20210730/Resource/MachineLearning/AmazonSageMakerModel')

' renders the element
AmazonSageMakerModelGroup('AmazonSageMakerModelGroup', 'Amazon Sage Maker Model Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
